@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -83,7 +83,7 @@ void CustomDebugSettingsPage::updateButtons()
 
 void CustomDebugSettingsPage::fillList(const LoggingCategory::List &list)
 {
-    Q_FOREACH (const LoggingCategory &cat, list) {
+    for (const LoggingCategory &cat : list) {
         QString ruleStr;
         ruleStr = cat.logName;
         switch (cat.loggingType) {
